# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKVideoCorePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkTemporalRegionPython
else:
    import _itkTemporalRegionPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
class itkTemporalRegion(itk.ITKCommonBasePython.itkRegion):
    r"""Proxy of C++ itkTemporalRegion class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def SetRealStart(self, s):
        r"""
        SetRealStart(self, s)

        Parameters
        ----------
        s: itkRealTimeStamp const

        """
        return _itkTemporalRegionPython.itkTemporalRegion_SetRealStart(self, s)

    def GetRealStart(self):
        r"""GetRealStart(self) -> itkRealTimeStamp"""
        return _itkTemporalRegionPython.itkTemporalRegion_GetRealStart(self)

    def SetRealDuration(self, d):
        r"""
        SetRealDuration(self, d)

        Parameters
        ----------
        d: itkRealTimeInterval const

        """
        return _itkTemporalRegionPython.itkTemporalRegion_SetRealDuration(self, d)

    def GetRealDuration(self):
        r"""GetRealDuration(self) -> itkRealTimeInterval"""
        return _itkTemporalRegionPython.itkTemporalRegion_GetRealDuration(self)

    def SetFrameStart(self, s):
        r"""
        SetFrameStart(self, s)

        Parameters
        ----------
        s: unsigned long const

        """
        return _itkTemporalRegionPython.itkTemporalRegion_SetFrameStart(self, s)

    def GetFrameStart(self):
        r"""GetFrameStart(self) -> unsigned long"""
        return _itkTemporalRegionPython.itkTemporalRegion_GetFrameStart(self)

    def SetFrameDuration(self, d):
        r"""
        SetFrameDuration(self, d)

        Parameters
        ----------
        d: unsigned long const

        """
        return _itkTemporalRegionPython.itkTemporalRegion_SetFrameDuration(self, d)

    def GetFrameDuration(self):
        r"""GetFrameDuration(self) -> unsigned long"""
        return _itkTemporalRegionPython.itkTemporalRegion_GetFrameDuration(self)
    __swig_destroy__ = _itkTemporalRegionPython.delete_itkTemporalRegion

    def IsEqualInFrames(self, region):
        r"""
        IsEqualInFrames(self, region) -> bool

        Parameters
        ----------
        region: itkTemporalRegion const &

        """
        return _itkTemporalRegionPython.itkTemporalRegion_IsEqualInFrames(self, region)

    def IsEqualInRealTime(self, region):
        r"""
        IsEqualInRealTime(self, region) -> bool

        Parameters
        ----------
        region: itkTemporalRegion const &

        """
        return _itkTemporalRegionPython.itkTemporalRegion_IsEqualInRealTime(self, region)

    def __eq__(self, region):
        r"""
        __eq__(self, region) -> bool

        Parameters
        ----------
        region: itkTemporalRegion const &

        """
        return _itkTemporalRegionPython.itkTemporalRegion___eq__(self, region)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkTemporalRegion const &

        """
        return _itkTemporalRegionPython.itkTemporalRegion___ne__(self, other)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkTemporalRegion
        __init__(self, arg0) -> itkTemporalRegion

        Parameters
        ----------
        arg0: itkTemporalRegion const &

        """
        _itkTemporalRegionPython.itkTemporalRegion_swiginit(self, _itkTemporalRegionPython.new_itkTemporalRegion(*args))

# Register itkTemporalRegion in _itkTemporalRegionPython:
_itkTemporalRegionPython.itkTemporalRegion_swigregister(itkTemporalRegion)

